@@ -109,7 +109,8 @@ class PythonPipWorkflow(BaseWorkflow):
         # folder
         if self.dependencies_dir and self.combine_dependencies:
             # when copying downloaded dependencies back to artifacts folder, don't exclude anything
-            if is_experimental_build_improvements_enabled(self.experimental_flags):
+            # symlinking python dependencies is disabled for now since it is breaking sam local commands
+            if False and is_experimental_build_improvements_enabled(self.experimental_flags):
                 self.actions.append(LinkSourceAction(self.dependencies_dir, artifacts_dir))
             else:
                 self.actions.append(CopySourceAction(self.dependencies_dir, artifacts_dir))
